@@ -4,9 +4,9 @@ Component for the estimation of the calibration coefficients  events
 
 import numpy as np
 import h5py
-from ctapipe.core import Component
+from lstchain.ctapipe_compat import Component
 from ctapipe.core import traits
-from ctapipe.core.traits import  Float, List, Path
+from ctapipe.core.traits import  Float, Path
 from lstchain.calib.camera.flatfield import FlatFieldCalculator
 from lstchain.calib.camera.pedestals import PedestalCalculator
 from ctapipe.containers import EventType
@@ -59,14 +59,11 @@ class CalibrationCalculator(Component):
         default_value='FlasherFlatFieldCalculator'
     )
 
-    classes = List([
-                    FlatFieldCalculator,
-                    PedestalCalculator
-                    ]
-                   + traits.classes_with_traits(FlatFieldCalculator)
-                   + traits.classes_with_traits(PedestalCalculator)
-
-                   )
+    classes = (
+        [FlatFieldCalculator, PedestalCalculator]
+        + traits.classes_with_traits(FlatFieldCalculator)
+        + traits.classes_with_traits(PedestalCalculator)
+    )
 
     def __init__(
         self,
