@@ -2,8 +2,8 @@ import h5py
 import numpy as np
 
 
-from ctapipe.core import Component
-from ctapipe.core.traits import Unicode
+from lstchain.ctapipe_compat import Component
+from ctapipe.core.traits import Path
 
 __all__ = [
     'TimeSamplingCorrection',
@@ -17,13 +17,11 @@ class TimeSamplingCorrection(Component):
         using Fourier series expansion.
     """
 
-    time_sampling_correction_path = Unicode(
-        '',
-        help='Path to the waveform sampling correction file',
-        allow_none = True,
+    time_sampling_correction_path = Path(
+        exists=True, directory_ok=False,
+        help='Path to time sampling correction file'
     ).tag(config=True)
 
-
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
 
