@@ -1,22 +1,14 @@
 #!/usr/bin/env python3
-
-"""
-Pipeline for the reconstruction of Energy, disp and gamma/hadron
-separation of events stored in a DL1 file.
-
-- Input: DL1 files and trained Random Forests.
-- Output: DL2 data file.
-
-Usage:
-
-$> python lstchain_dl1_to_dl2.py
---input-file dl1_LST-1.Run02033.0137.h5
---path-models ./trained_models
-
+__doc__ = """
+Run the DL1 to DL2 step: Pipeline for the reconstruction of Energy, disp and gamma/hadron
+separation of events stored in a DL1 file. It takes DL1 file(s) and trained Random Forests as input 
+and outputs DL2 data file(s).
+Run lstchain_dl1_to_dl2 --help to see the options.
 """
 
 import argparse
-import os
+from pathlib import Path
+import joblib
 
 import numpy as np
 import pandas as pd
@@ -45,47 +37,46 @@ from lstchain.io.io import (
 from lstchain.reco import dl1_to_dl2
 from lstchain.reco.utils import filter_events, impute_pointing, add_delta_t_key
 
-parser = argparse.ArgumentParser(description="DL1 to DL2")
+
+parser = argparse.ArgumentParser(description=__doc__)
 
 # Required arguments
-parser.add_argument('--input-file', '-f', type=str,
-                    dest='input_file',
-                    help='path to a DL1 HDF5 file',
-                    default=None, required=True)
+parser.add_argument('--input-files', '-f',
+                    type=Path,
+                    nargs='+',
+                    dest='input_files',
+                    help='Path (or list of paths) to a DL1 HDF5 file',
+                    required=True)
 
-parser.add_argument('--path-models', '-p', action='store', type=str,
+parser.add_argument('--path-models', '-p',
+                    action='store',
+                    type=Path,
                     dest='path_models',
                     help='Path where to find the trained RF',
                     default='./trained_models')
 
 # Optional arguments
-parser.add_argument('--output-dir', '-o', action='store', type=str,
+parser.add_argument('--output-dir', '-o',
+                    action='store',
+                    type=Path,
                     dest='output_dir',
                     help='Path where to store the reco dl2 events',
                     default='./dl2_data')
 
-parser.add_argument('--config', '-c', action='store', type=str,
+parser.add_argument('--config', '-c',
+                    action='store',
+                    type=Path,
                     dest='config_file',
                     help='Path to a configuration file. If none is given, a standard configuration is applied',
-                    default=None, required=False)
+                    default=None,
+                    required=False)
 
 
-def main():
-    args = parser.parse_args()
-
-    custom_config = {}
-    if args.config_file is not None:
-        try:
-            custom_config = read_configuration_file(os.path.abspath(args.config_file))
-        except("Custom configuration could not be loaded !!!"):
-            pass
-
-    config = replace_config(standard_config, custom_config)
-
-    data = pd.read_hdf(args.input_file, key=dl1_params_lstcam_key)
+def apply_to_file(filename, models_dict, output_dir, config):
+    data = pd.read_hdf(filename, key=dl1_params_lstcam_key)
 
     if 'lh_fit_config' in config.keys():
-        lhfit_data = pd.read_hdf(args.input_file, key=dl1_likelihood_params_lstcam_key)
+        lhfit_data = pd.read_hdf(filename, key=dl1_likelihood_params_lstcam_key)
         if np.all(lhfit_data['obs_id'] == data['obs_id']) & np.all(lhfit_data['event_id'] == data['event_id']):
             lhfit_data.drop({'obs_id', 'event_id'}, axis=1, inplace=True)
         lhfit_keys = lhfit_data.keys()
@@ -97,23 +88,14 @@ def main():
     # Dealing with pointing missing values. This happened when `ucts_time` was invalid.
     if 'alt_tel' in data.columns and 'az_tel' in data.columns \
             and (np.isnan(data.alt_tel).any() or np.isnan(data.az_tel).any()):
-        # make sure there is a least one good pointing value to interp from.
+        # make sure there is at least one good pointing value to interp from.
         if np.isfinite(data.alt_tel).any() and np.isfinite(data.az_tel).any():
             data = impute_pointing(data)
         else:
             data.alt_tel = - np.pi / 2.
             data.az_tel = - np.pi / 2.
 
-    # Get trained RF path for reconstruction:
-    file_reg_energy = os.path.join(args.path_models, 'reg_energy.sav')
-    file_cls_gh = os.path.join(args.path_models, 'cls_gh.sav')
-    if config['disp_method'] == 'disp_vector':
-        file_disp_vector = os.path.join(args.path_models, 'reg_disp_vector.sav')
-    elif config['disp_method'] == 'disp_norm_sign':
-        file_disp_norm = os.path.join(args.path_models, 'reg_disp_norm.sav')
-        file_disp_sign = os.path.join(args.path_models, 'cls_disp_sign.sav')
-
-    subarray_info = SubarrayDescription.from_hdf(args.input_file)
+    subarray_info = SubarrayDescription.from_hdf(filename)
     tel_id = config["allowed_tels"][0] if "allowed_tels" in config else 1
     focal_length = subarray_info.tel[tel_id].optics.equivalent_focal_length
 
@@ -130,20 +112,26 @@ def main():
                              )
 
         if config['disp_method'] == 'disp_vector':
-            dl2 = dl1_to_dl2.apply_models(data, file_cls_gh, file_reg_energy, reg_disp_vector=file_disp_vector,
+            dl2 = dl1_to_dl2.apply_models(data,
+                                          models_dict['cls_gh'],
+                                          models_dict['reg_energy'],
+                                          reg_disp_vector=models_dict['disp_vector'],
                                           focal_length=focal_length,
                                           custom_config=config)
         elif config['disp_method'] == 'disp_norm_sign':
-            dl2 = dl1_to_dl2.apply_models(data, file_cls_gh, file_reg_energy, reg_disp_norm=file_disp_norm,
-                                          cls_disp_sign=file_disp_sign,
-                                          focal_length=focal_length, custom_config=config)
+            dl2 = dl1_to_dl2.apply_models(data,
+                                          models_dict['cls_gh'],
+                                          models_dict['reg_energy'],
+                                          reg_disp_norm=models_dict['disp_norm'],
+                                          cls_disp_sign=models_dict['disp_sign'],
+                                          focal_length=focal_length,
+                                          custom_config=config)
 
     # Source-dependent analysis
     if config['source_dependent']:
-
         # if source-dependent parameters are already in dl1 data, just read those data.
-        if dl1_params_src_dep_lstcam_key in get_dataset_keys(args.input_file):
-            data_srcdep = get_srcdep_params(args.input_file)
+        if dl1_params_src_dep_lstcam_key in get_dataset_keys(filename):
+            data_srcdep = get_srcdep_params(filename)
 
         # if not, source-dependent parameters are added now
         else:
@@ -165,13 +153,20 @@ def main():
                                                    )
 
             if config['disp_method'] == 'disp_vector':
-                dl2_df = dl1_to_dl2.apply_models(data_with_srcdep_param, file_cls_gh, file_reg_energy,
-                                                 reg_disp_vector=file_disp_vector,
-                                                 focal_length=focal_length, custom_config=config)
+                dl2_df = dl1_to_dl2.apply_models(data_with_srcdep_param,
+                                                 models_dict['cls_gh'],
+                                                 models_dict['reg_energy'],
+                                                 reg_disp_vector=models_dict['disp_vector'],
+                                                 focal_length=focal_length,
+                                                 custom_config=config)
             elif config['disp_method'] == 'disp_norm_sign':
-                dl2_df = dl1_to_dl2.apply_models(data_with_srcdep_param, file_cls_gh, file_reg_energy,
-                                                 reg_disp_norm=file_disp_norm, cls_disp_sign=file_disp_sign,
-                                                 focal_length=focal_length, custom_config=config)
+                dl2_df = dl1_to_dl2.apply_models(data_with_srcdep_param,
+                                                 models_dict['cls_gh'],
+                                                 models_dict['reg_energy'],
+                                                 reg_disp_norm=models_dict['disp_norm'],
+                                                 cls_disp_sign=models_dict['disp_sign'],
+                                                 focal_length=focal_length,
+                                                 custom_config=config)
 
             dl2_srcdep = dl2_df.drop(srcindep_keys, axis=1)
             dl2_srcdep_dict[k] = dl2_srcdep
@@ -179,13 +174,13 @@ def main():
             if i == 0:
                 dl2_srcindep = dl2_df[srcindep_keys]
 
-    os.makedirs(args.output_dir, exist_ok=True)
-    output_file = os.path.join(args.output_dir, os.path.basename(args.input_file).replace('dl1', 'dl2', 1))
+    output_dir.mkdir(exist_ok=True)
+    output_file = output_dir.joinpath(filename.name.replace('dl1', 'dl2', 1))
 
-    if os.path.exists(output_file):
+    if output_file.exists():
         raise IOError(output_file + ' exists, exiting.')
 
-    dl1_keys = get_dataset_keys(args.input_file)
+    dl1_keys = get_dataset_keys(filename)
 
     if dl1_images_lstcam_key in dl1_keys:
         dl1_keys.remove(dl1_images_lstcam_key)
@@ -202,7 +197,7 @@ def main():
     metadata = global_metadata()
     write_metadata(metadata, output_file)
 
-    with open_file(args.input_file, 'r') as h5in:
+    with open_file(filename, 'r') as h5in:
         with open_file(output_file, 'a') as h5out:
 
             # Write the selected DL1 info
@@ -237,5 +232,31 @@ def main():
                         meta=metadata)
 
 
+def main():
+    args = parser.parse_args()
+
+    custom_config = {}
+    if args.config_file is not None:
+        try:
+            custom_config = read_configuration_file(args.config_file.absolute())
+        except("Custom configuration could not be loaded !!!"):
+            pass
+
+    config = replace_config(standard_config, custom_config)
+
+    # load models once and for all
+    models_dict = {'reg_energy': joblib.load(Path(args.path_models, 'reg_energy.sav'))}
+    models_dict['cls_gh'] = joblib.load(Path(args.path_models, 'cls_gh.sav'))
+    if config['disp_method'] == 'disp_vector':
+        models_dict['disp_vector'] = joblib.load(Path(args.path_models, 'reg_disp_vector.sav'))
+    elif config['disp_method'] == 'disp_norm_sign':
+        models_dict['disp_norm'] = joblib.load(Path(args.path_models, 'reg_disp_norm.sav'))
+        models_dict['disp_sign'] = joblib.load(Path(args.path_models, 'cls_disp_sign.sav'))
+
+    for filename in args.input_files:
+        apply_to_file(filename, models_dict, args.output_dir, config)
+
+
+
 if __name__ == '__main__':
     main()
