@@ -11,11 +11,13 @@ import joblib
 import matplotlib
 import matplotlib.pyplot as plt
 import numpy as np
+
 from astropy.io.misc.hdf5 import (
     read_table_hdf5,
     write_table_hdf5,
 )
-from astropy.table import Table
+from astropy.table import Table, QTable
+
 from matplotlib.cm import get_cmap
 from scipy.stats import norm
 
@@ -50,9 +52,7 @@ def plot_features(data, true_hadroness=False):
         True: True gammas and proton events are plotted (they are separated using true hadroness).
         False: Gammas and protons are separated using reconstructed hadroness (hadro_rec).
     """
-    hadro = "reco_type"
-    if true_hadroness:
-        hadro = "mc_type"
+    hadro = "mc_type" if true_hadroness else "reco_type"
 
     # Energy distribution
     plt.subplot(331)
@@ -178,10 +178,12 @@ def energy_results(dl2_data, points_outfile=None, plot_outfile=None):
     """
     fig, axes = plt.subplots(2, 2, figsize=(12, 8))
 
-    ctaplot.resolution_per_energy(dl2_data.mc_energy, dl2_data.reco_energy, dl2_data.reco_energy)
-    ctaplot.plot_energy_resolution(dl2_data.mc_energy, dl2_data.reco_energy, ax=axes[0, 0], bias_correction=False)
+    ctaplot.plot_energy_resolution(dl2_data.mc_energy.values * u.TeV,
+                                   dl2_data.reco_energy.values * u.TeV,
+                                   ax=axes[0, 0], bias_correction=False)
     ctaplot.plot_energy_resolution_cta_requirement('north', ax=axes[0, 0], color='black')
-    ctaplot.plot_energy_bias(dl2_data.mc_energy, dl2_data.reco_energy, ax=axes[1, 0])
+
+    ctaplot.plot_energy_bias(dl2_data.mc_energy.values * u.TeV, dl2_data.reco_energy.values * u.TeV, ax=axes[1, 0])
     ctaplot.plot_migration_matrix(dl2_data.mc_energy.apply(np.log10),
                                   dl2_data.reco_energy.apply(np.log10),
                                   ax=axes[0, 1],
@@ -197,15 +199,17 @@ def energy_results(dl2_data, points_outfile=None, plot_outfile=None):
     axes[0, 0].label_outer()
     axes[1, 0].set_title("")
     axes[1, 0].set_ylabel("Energy bias")
-    for ax in axes.ravel(): ax.grid(which='both')
+    for ax in axes.ravel():
+        ax.grid(True, which='both')
     axes[1, 1].remove()
 
     fig.tight_layout()
 
     if points_outfile:
-        e_bins, e_res = ctaplot.energy_resolution_per_energy(dl2_data.mc_energy, dl2_data.reco_energy)
-        e_bins, e_bias = ctaplot.energy_bias(dl2_data.mc_energy, dl2_data.reco_energy)
-        write_energy_resolutions(points_outfile, e_bins * u.TeV, e_res, e_bias)
+        e_bins, e_res = ctaplot.energy_resolution_per_energy(dl2_data.mc_energy.values * u.TeV,
+                                                             dl2_data.reco_energy.values * u.TeV)
+        e_bins, e_bias = ctaplot.energy_bias(dl2_data.mc_energy.values * u.TeV, dl2_data.reco_energy.values * u.TeV)
+        write_energy_resolutions(points_outfile, e_bins, e_res, e_bias)
 
     if plot_outfile:
         fig.savefig(plot_outfile)
@@ -220,13 +224,13 @@ def write_energy_resolutions(outfile, e_bins, res, bias=None, overwrite=False, a
     Parameters
     ----------
     outfile: str
-    e_bins: `numpy.ndarray`
+    e_bins: `numpy.ndarray` or `astropy.Quantity`
     res: `np.ndarray`
     bias: `np.ndarray`
     overwrite
     append
     """
-    e_bins_t = Table(data=e_bins[..., np.newaxis], names=['energy_bins'])
+    e_bins_t = QTable(data=e_bins[..., np.newaxis], names=['energy_bins'])
 
     data = res
     names = ['energy_res', 'energy_res_err_lo', 'energy_res_err_hi']
@@ -246,12 +250,12 @@ def write_angular_resolutions(outfile, e_bins, res, overwrite=False, append=True
     Parameters
     ----------
     outfile: str
-    e_bins: `numpy.ndarray`
+    e_bins: `numpy.ndarray` or `astropy.Quantity`
     res: `np.ndarray`
     overwrite
     append
     """
-    e_bins_t = Table(data=e_bins[..., np.newaxis], names=['energy_bins'])
+    e_bins_t = QTable(data=e_bins[..., np.newaxis], names=['energy_bins'])
 
     data = res
     names = ['angular_res', 'angular_res_err_lo', 'angular_res_err_hi']
@@ -290,9 +294,7 @@ def plot_disp(data, true_hadroness=False):
         False: Gammas and protons are separated using reconstructed
         hadroness (hadro_rec)
     """
-    hadro = "reco_type"
-    if true_hadroness:
-        hadro = "mc_type"
+    hadro = "mc_type" if true_hadroness else "reco_type"
 
     gammas = data[data[hadro] == 0]
 
@@ -367,9 +369,7 @@ def plot_pos(data, true_hadroness=False):
     False: Gammas and protons are separated using reconstructed
     hadroness (hadro_rec)
     """
-    hadro = "reco_type"
-    if true_hadroness:
-        hadro = "mc_type"
+    hadro = "mc_type" if true_hadroness else "reco_type"
 
     # True position
 
@@ -451,13 +451,10 @@ def plot_importances(model, features_names, ax=None, **kwargs):
     std = np.std([tree.feature_importances_ for tree in model.estimators_], axis=0)
     indices = np.argsort(importances)
 
-    ordered_features = []
-    for index in indices:
-        ordered_features = ordered_features + [features_names[index]]
-
+    ordered_features = [features_names[index] for index in indices]
     ax.set_title("Feature importances (gini index)")
 
-    ax.barh(range(len(features_names)),
+    ax.barh(ordered_features,
             importances[indices],
             xerr=std[indices],
             align="center",
@@ -465,7 +462,7 @@ def plot_importances(model, features_names, ax=None, **kwargs):
             )
 
     ax.set_yticks(range(len(features_names)))
-    ax.set_yticklabels(np.array(features_names)[indices])
+    ax.set_yticklabels(ordered_features)
     ax.grid()
 
     return ax
@@ -599,8 +596,8 @@ def plot_energy_resolution(dl2_data, ax=None, bias_correction=False, cta_req_nor
     ax: `matplotlib.pyplot.axes`
     """
 
-    ax = ctaplot.plot_energy_resolution(dl2_data.mc_energy,
-                                        dl2_data.reco_energy,
+    ax = ctaplot.plot_energy_resolution(dl2_data.mc_energy.values * u.TeV,
+                                        dl2_data.reco_energy.values * u.TeV,
                                         ax=ax,
                                         bias_correction=bias_correction,
                                         **kwargs,
@@ -632,11 +629,11 @@ def plot_angular_resolution(dl2_data, ax=None, bias_correction=False, cta_req_no
     ax: `matplotlib.pyplot.axes`
     """
 
-    ax = ctaplot.plot_angular_resolution_per_energy(dl2_data.reco_alt,
-                                                    dl2_data.reco_az,
-                                                    dl2_data.mc_alt,
-                                                    dl2_data.mc_az,
-                                                    dl2_data.reco_energy,
+    ax = ctaplot.plot_angular_resolution_per_energy(dl2_data.mc_alt.values * u.rad,
+                                                    dl2_data.reco_alt.values * u.rad,
+                                                    dl2_data.mc_az.values * u.rad,
+                                                    dl2_data.reco_az.values * u.rad,
+                                                    dl2_data.reco_energy.values * u.TeV,
                                                     ax=ax,
                                                     bias_correction=bias_correction,
                                                     **kwargs
@@ -666,21 +663,21 @@ def direction_results(dl2_data, points_outfile=None, plot_outfile=None):
 
     fig, axes = plt.subplots(2, 2, figsize=(15, 12))
 
-    ax = ctaplot.plot_theta2(dl2_data.reco_alt,
-                             dl2_data.reco_az,
-                             dl2_data.mc_alt,
-                             dl2_data.mc_az,
+    ax = ctaplot.plot_theta2(dl2_data.mc_alt.values * u.rad,
+                             dl2_data.reco_alt.values * u.rad,
+                             dl2_data.mc_az.values * u.rad,
+                             dl2_data.reco_az.values * u.rad,
                              ax=axes[0, 0],
                              bins=100,
                              range=(0, 1),
                              )
     ax.grid()
 
-    ctaplot.plot_angular_resolution_per_energy(dl2_data.reco_alt,
-                                               dl2_data.reco_az,
-                                               dl2_data.mc_alt,
-                                               dl2_data.mc_az,
-                                               dl2_data.reco_energy,
+    ctaplot.plot_angular_resolution_per_energy(dl2_data.mc_alt.values * u.rad,
+                                               dl2_data.reco_alt.values * u.rad,
+                                               dl2_data.mc_az.values * u.rad,
+                                               dl2_data.reco_az.values * u.rad,
+                                               dl2_data.reco_energy.values * u.TeV,
                                                ax=axes[0, 1],
                                                )
 
@@ -688,8 +685,8 @@ def direction_results(dl2_data, points_outfile=None, plot_outfile=None):
     axes[0, 1].grid()
     axes[0, 1].legend()
 
-    ctaplot.plot_migration_matrix(dl2_data.mc_alt,
-                                  dl2_data.reco_alt,
+    ctaplot.plot_migration_matrix(dl2_data.mc_alt.values * u.rad,
+                                  dl2_data.reco_alt.values * u.rad,
                                   ax=axes[1, 0],
                                   colorbar=True,
                                   xy_line=True,
@@ -699,8 +696,8 @@ def direction_results(dl2_data, points_outfile=None, plot_outfile=None):
     axes[1, 0].set_xlabel('simu alt [rad]')
     axes[1, 0].set_ylabel('reco alt [rad]')
 
-    ctaplot.plot_migration_matrix(dl2_data.mc_az,
-                                  dl2_data.reco_az,
+    ctaplot.plot_migration_matrix(dl2_data.mc_az.values * u.rad,
+                                  dl2_data.reco_az.values * u.rad,
                                   ax=axes[1, 1],
                                   colorbar=True,
                                   xy_line=True,
@@ -713,11 +710,11 @@ def direction_results(dl2_data, points_outfile=None, plot_outfile=None):
     fig.tight_layout()
 
     if points_outfile:
-        e_bins, ang_res = ctaplot.angular_resolution_per_energy(dl2_data.reco_alt,
-                                                                dl2_data.reco_az,
-                                                                dl2_data.mc_alt,
-                                                                dl2_data.mc_az,
-                                                                dl2_data.reco_energy,
+        e_bins, ang_res = ctaplot.angular_resolution_per_energy(dl2_data.mc_alt.values * u.rad,
+                                                                dl2_data.reco_alt.values * u.rad,
+                                                                dl2_data.mc_az.values * u.rad,
+                                                                dl2_data.reco_az.values * u.rad,
+                                                                dl2_data.reco_energy.values * u.TeV,
                                                                 )
 
         write_angular_resolutions(points_outfile, e_bins * u.TeV, ang_res * u.rad)
